@@ -18,9 +18,20 @@ class EnvDataStore:
 
         self.__env[env_var].append(value)
 
-    def get(self, env_var: str) -> Any:
-        if isinstance(self.__env[env_var], list):
-            return os.pathsep.join(self.__env[env_var])
+    def get(self, env_var: str) -> Any | None:
+        """Retrieve environment variable from store.
+
+        Args:
+            env_var (str): Environment variable to retrieve.
+
+        Returns:
+            Any | None: Environment variable value. Returns None if variable is not in store.
+        """
+        try:
+            if type(self.__env[env_var]) == list:
+                return os.pathsep.join(self.__env[env_var])
+        except KeyError:
+            return None
 
     @property
     def _raw_env(self) -> Dict[str, Any]:
